@@ -100,8 +100,20 @@ def handle_brownie_generate(args: argparse.Namespace):
     with open(build_file_path, "r") as ifp:
         build = json.load(ifp)
 
+    relpath = os.path.relpath(project_directory, args.outdir)
+    splitted_relpath = [
+        f'"{item}"' for item in relpath.split(os.sep)
+    ]  # os.sep => '/' for unix '\' for windows subsystems
+    splitted_relpath_string = ",".join(splitted_relpath)
+
     abi = build["abi"]
-    interface = generate_brownie_interface(abi, args.name)
+    interface = generate_brownie_interface(
+        abi,
+        build,
+        args.name,
+        splitted_relpath_string,
+        prod=args.prod,
+    )
     write_file(interface, os.path.join(args.outdir, args.name + ".py"))
 
 
@@ -381,6 +393,11 @@ def generate_argument_parser() -> argparse.ArgumentParser:
         required=True,
         help=f"Path to brownie project directory",
     )
+    generate_brownie_parser.add_argument(
+        "--prod",
+        action="store_true",
+        help="Generate shippable python interface, in which abi and bytecode will be included inside the generated file",
+    )
     generate_brownie_parser.set_defaults(func=handle_brownie_generate)
 
     generate_parser = subcommands.add_parser(
